# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mozart_api.api_client import ApiClient
from mozart_api.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class SoundApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def activate_listening_mode(self, id, **kwargs):  # noqa: E501
        """Activate a listening mode  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_listening_mode(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.activate_listening_mode_with_http_info(id, **kwargs)  # noqa: E501

    def activate_listening_mode_with_http_info(self, id, **kwargs):  # noqa: E501
        """Activate a listening mode  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.activate_listening_mode_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int id: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["id"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method activate_listening_mode" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and (
            "id" not in local_var_params or local_var_params["id"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `id` when calling `activate_listening_mode`"
            )  # noqa: E501

        if (
            self.api_client.client_side_validation
            and "id" in local_var_params
            and local_var_params["id"] < 0
        ):  # noqa: E501
            raise ApiValueError(
                "Invalid value for parameter `id` when calling `activate_listening_mode`, must be a value greater than or equal to `0`"
            )  # noqa: E501
        collection_formats = {}

        path_params = {}
        if "id" in local_var_params:
            path_params["id"] = local_var_params["id"]  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/listening-modes/{id}/activate",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_active_listening_mode(self, **kwargs):  # noqa: E501
        """Get the active listening mode  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_listening_mode(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListeningModeRef
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_active_listening_mode_with_http_info(**kwargs)  # noqa: E501

    def get_active_listening_mode_with_http_info(self, **kwargs):  # noqa: E501
        """Get the active listening mode  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_active_listening_mode_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListeningModeRef, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_active_listening_mode" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/listening-modes/active",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ListeningModeRef",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_current_volume(self, **kwargs):  # noqa: E501
        """Get the current volume state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_volume(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VolumeState
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_current_volume_with_http_info(**kwargs)  # noqa: E501

    def get_current_volume_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current volume state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_current_volume_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VolumeState, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_current_volume" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/volume",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="VolumeState",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_listening_mode_set(self, **kwargs):  # noqa: E501
        """Get available listening modes that match the current role (standalone or multichannel).   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_listening_mode_set(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ListeningMode]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_listening_mode_set_with_http_info(**kwargs)  # noqa: E501

    def get_listening_mode_set_with_http_info(self, **kwargs):  # noqa: E501
        """Get available listening modes that match the current role (standalone or multichannel).   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_listening_mode_set_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ListeningMode], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_listening_mode_set" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/listening-modes",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[ListeningMode]",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_sound_features(self, **kwargs):  # noqa: E501
        """Get available sound features that match the current role (standalone or multichannel).   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sound_features(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: dict(str, SoundFeatureSet)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_sound_features_with_http_info(**kwargs)  # noqa: E501

    def get_sound_features_with_http_info(self, **kwargs):  # noqa: E501
        """Get available sound features that match the current role (standalone or multichannel).   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_sound_features_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(dict(str, SoundFeatureSet), status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_sound_features" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/features",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="dict(str, SoundFeatureSet)",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def get_volume_settings(self, **kwargs):  # noqa: E501
        """Get the current volume settings for default and maximum volume level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_volume_settings(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: VolumeSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.get_volume_settings_with_http_info(**kwargs)  # noqa: E501

    def get_volume_settings_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current volume settings for default and maximum volume level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_volume_settings_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(VolumeSettings, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = []
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_volume_settings" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/volume/settings",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="VolumeSettings",  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_current_volume_level(self, volume_level, **kwargs):  # noqa: E501
        """Set the current volume level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_current_volume_level(volume_level, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VolumeLevel volume_level: The volume level to apply (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_current_volume_level_with_http_info(
            volume_level, **kwargs
        )  # noqa: E501

    def set_current_volume_level_with_http_info(
        self, volume_level, **kwargs
    ):  # noqa: E501
        """Set the current volume level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_current_volume_level_with_http_info(volume_level, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VolumeLevel volume_level: The volume level to apply (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["volume_level"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_current_volume_level" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'volume_level' is set
        if self.api_client.client_side_validation and (
            "volume_level" not in local_var_params
            or local_var_params["volume_level"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `volume_level` when calling `set_current_volume_level`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "volume_level" in local_var_params:
            body_params = local_var_params["volume_level"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/volume/level",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_sound_settings_adjustments_bass(self, bass, **kwargs):  # noqa: E501
        """Update the sound settings adjustments for bass  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_bass(bass, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Bass bass: the bass level (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_sound_settings_adjustments_bass_with_http_info(
            bass, **kwargs
        )  # noqa: E501

    def set_sound_settings_adjustments_bass_with_http_info(
        self, bass, **kwargs
    ):  # noqa: E501
        """Update the sound settings adjustments for bass  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_bass_with_http_info(bass, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Bass bass: the bass level (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["bass"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_sound_settings_adjustments_bass" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'bass' is set
        if self.api_client.client_side_validation and (
            "bass" not in local_var_params
            or local_var_params["bass"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `bass` when calling `set_sound_settings_adjustments_bass`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "bass" in local_var_params:
            body_params = local_var_params["bass"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/settings/adjustments/bass",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_sound_settings_adjustments_directivity(
        self, directivity, **kwargs
    ):  # noqa: E501
        """Update the sound settings adjustments for directivity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_directivity(directivity, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Directivity directivity: the directivity (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_sound_settings_adjustments_directivity_with_http_info(
            directivity, **kwargs
        )  # noqa: E501

    def set_sound_settings_adjustments_directivity_with_http_info(
        self, directivity, **kwargs
    ):  # noqa: E501
        """Update the sound settings adjustments for directivity  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_directivity_with_http_info(directivity, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Directivity directivity: the directivity (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["directivity"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_sound_settings_adjustments_directivity" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'directivity' is set
        if self.api_client.client_side_validation and (
            "directivity" not in local_var_params
            or local_var_params["directivity"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `directivity` when calling `set_sound_settings_adjustments_directivity`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "directivity" in local_var_params:
            body_params = local_var_params["directivity"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/settings/adjustments/directivity",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_sound_settings_adjustments_loudness(self, loudness, **kwargs):  # noqa: E501
        """Update the sound settings adjustments for loudness  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_loudness(loudness, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Loudness loudness: the loudness mode (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_sound_settings_adjustments_loudness_with_http_info(
            loudness, **kwargs
        )  # noqa: E501

    def set_sound_settings_adjustments_loudness_with_http_info(
        self, loudness, **kwargs
    ):  # noqa: E501
        """Update the sound settings adjustments for loudness  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_loudness_with_http_info(loudness, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Loudness loudness: the loudness mode (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["loudness"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_sound_settings_adjustments_loudness" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'loudness' is set
        if self.api_client.client_side_validation and (
            "loudness" not in local_var_params
            or local_var_params["loudness"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `loudness` when calling `set_sound_settings_adjustments_loudness`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "loudness" in local_var_params:
            body_params = local_var_params["loudness"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/settings/adjustments/loudness",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_sound_settings_adjustments_treble(self, treble, **kwargs):  # noqa: E501
        """Update the sound settings adjustments for treble  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_treble(treble, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Treble treble: the treble level (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_sound_settings_adjustments_treble_with_http_info(
            treble, **kwargs
        )  # noqa: E501

    def set_sound_settings_adjustments_treble_with_http_info(
        self, treble, **kwargs
    ):  # noqa: E501
        """Update the sound settings adjustments for treble  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_sound_settings_adjustments_treble_with_http_info(treble, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Treble treble: the treble level (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["treble"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_sound_settings_adjustments_treble" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'treble' is set
        if self.api_client.client_side_validation and (
            "treble" not in local_var_params
            or local_var_params["treble"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `treble` when calling `set_sound_settings_adjustments_treble`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "treble" in local_var_params:
            body_params = local_var_params["treble"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/settings/adjustments/treble",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_volume_mute(self, volume_mute, **kwargs):  # noqa: E501
        """Set the volume mute state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_volume_mute(volume_mute, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VolumeMute volume_mute: The mute state to apply (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_volume_mute_with_http_info(volume_mute, **kwargs)  # noqa: E501

    def set_volume_mute_with_http_info(self, volume_mute, **kwargs):  # noqa: E501
        """Set the volume mute state  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_volume_mute_with_http_info(volume_mute, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VolumeMute volume_mute: The mute state to apply (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["volume_mute"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_volume_mute" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'volume_mute' is set
        if self.api_client.client_side_validation and (
            "volume_mute" not in local_var_params
            or local_var_params["volume_mute"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `volume_mute` when calling `set_volume_mute`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "volume_mute" in local_var_params:
            body_params = local_var_params["volume_mute"]
        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/volume/mute",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def set_volume_settings(self, volume_settings, **kwargs):  # noqa: E501
        """Set the current volume settings for default and maximum volume level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_volume_settings(volume_settings, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VolumeSettings volume_settings: The settings to apply (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.set_volume_settings_with_http_info(
            volume_settings, **kwargs
        )  # noqa: E501

    def set_volume_settings_with_http_info(
        self, volume_settings, **kwargs
    ):  # noqa: E501
        """Set the current volume settings for default and maximum volume level  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.set_volume_settings_with_http_info(volume_settings, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param VolumeSettings volume_settings: The settings to apply (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["volume_settings"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_volume_settings" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'volume_settings' is set
        if self.api_client.client_side_validation and (
            "volume_settings" not in local_var_params
            or local_var_params["volume_settings"] is None  # noqa: E501
        ):  # noqa: E501
            raise ApiValueError(
                "Missing the required parameter `volume_settings` when calling `set_volume_settings`"
            )  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "volume_settings" in local_var_params:
            body_params = local_var_params["volume_settings"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/sound/volume/settings",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class OverlayPlayRequestCommon(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"volume_absolute": "int"}

    attribute_map = {"volume_absolute": "volumeAbsolute"}

    def __init__(
        self, volume_absolute: Optional[int] = None, local_vars_configuration=None
    ):  # noqa: E501
        """OverlayPlayRequestCommon - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._volume_absolute = None
        self.discriminator = None

        self.volume_absolute = volume_absolute

    @property
    def volume_absolute(self):
        # type: () -> int
        """Gets the volume_absolute of this OverlayPlayRequestCommon.  # noqa: E501

        An optional absolute volume level at which to play the URI. If not provided, the URI will play at the currently configured volume level on the product. The level should be provided in volume steps [0, 100]   # noqa: E501

        :return: The volume_absolute of this OverlayPlayRequestCommon.  # noqa: E501
        :rtype: int
        """
        return self._volume_absolute

    @volume_absolute.setter
    def volume_absolute(self, volume_absolute):
        # type: (int) -> None
        """Sets the volume_absolute of this OverlayPlayRequestCommon.

        An optional absolute volume level at which to play the URI. If not provided, the URI will play at the currently configured volume level on the product. The level should be provided in volume steps [0, 100]   # noqa: E501

        :param volume_absolute: The volume_absolute of this OverlayPlayRequestCommon.  # noqa: E501
        :type volume_absolute: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and volume_absolute is not None
            and volume_absolute > 100
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `volume_absolute`, must be a value less than or equal to `100`"
            )  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and volume_absolute is not None
            and volume_absolute < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `volume_absolute`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._volume_absolute = volume_absolute

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OverlayPlayRequestCommon):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OverlayPlayRequestCommon):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.room_compensation_info import RoomCompensationInfo  # noqa: E501
from mozart_api.rest import ApiException


class TestRoomCompensationInfo(unittest.TestCase):
    """RoomCompensationInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test RoomCompensationInfo
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.room_compensation_info.RoomCompensationInfo()  # noqa: E501
        if include_optional:
            return RoomCompensationInfo(
                debug=mozart_api.models.room_compensation_debug.RoomCompensationDebug(
                    value=True,
                ),
                enabled=mozart_api.models.room_compensation_enabled.RoomCompensationEnabled(
                    value=True,
                ),
                last_result=mozart_api.models.room_compensation_result.RoomCompensationResult(
                    compensation=[
                        mozart_api.models.room_compensation_response.RoomCompensationResponse(
                            frequency=56,
                            gain=1.337,
                        )
                    ],
                    measured_response=[
                        mozart_api.models.room_compensation_response.RoomCompensationResponse(
                            frequency=56,
                            gain=1.337,
                        )
                    ],
                    placement="free",
                    reference_response=[
                        mozart_api.models.room_compensation_response.RoomCompensationResponse(
                            frequency=56,
                            gain=1.337,
                        )
                    ],
                    speaker_group_suggestion=mozart_api.models.speaker_group.SpeakerGroup(
                        crossover_frequency=20,
                        enable_phase_compensation=True,
                        friendly_name="0",
                        id="0",
                        is_deleteable=True,
                        items=[
                            mozart_api.models.speaker_group_member.SpeakerGroupMember(
                                distance=0,
                                friendly_name="0",
                                gain=-24,
                                id="0",
                                location=mozart_api.models.speaker_group_member_location.SpeakerGroupMember_location(
                                    x=56,
                                    y=56,
                                    z=56,
                                ),
                                redirection_level=-100,
                                role="0",
                                type="0",
                            )
                        ],
                        room_compensation_id="0",
                        speaker_preset=0,
                    ),
                    time_stamp=datetime.datetime.strptime(
                        "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                    ),
                ),
                last_run=null,
                type=mozart_api.models.room_compensation_type.RoomCompensationType(
                    value="simple",
                ),
                version=mozart_api.models.room_compensation_version.RoomCompensationVersion(
                    algorithm=0,
                    coefficients=0,
                ),
            )
        else:
            return RoomCompensationInfo()

    def testRoomCompensationInfo(self):
        """Test RoomCompensationInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional


from mozart_api.configuration import Configuration


class RoomCompensationMeasurementError(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"error": "str", "speaker_id": "str"}

    attribute_map = {"error": "error", "speaker_id": "speakerId"}

    def __init__(
        self,
        error: Optional["RoomCompensationMeasurementError.LTypeError"] = None,
        speaker_id: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """RoomCompensationMeasurementError - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._error = None
        self._speaker_id = None
        self.discriminator = None

        if error is not None:
            self.error = error
        if speaker_id is not None:
            self.speaker_id = speaker_id

    LTypeError = Literal[
        "noError",
        "lowSignal",
        "speakerSilent",
        "noisyLeftMicrophone",
        "noisyRightMicrophone",
        "noisyExternalMicrophone",
        "externalMicrophoneLocation",
        "externalMicrophoneMissing",
        "microphonesDisabled",
        "noisyMeasurement",
        "internalError",
    ]

    @property
    def error(self):
        # type: () -> 'RoomCompensationMeasurementError.LTypeError'
        """Gets the error of this RoomCompensationMeasurementError.  # noqa: E501

        noError:   The measurement went OK. lowSignal:   When there is too low signal in the recording, e.g. due to a loudspeaker being placed at   too great a distance from the microphone. speakerSilent:   No signal could be measured.   Could be because:     - The speaker is powered off or not connected.     - The left/right switch on a wired powerlink speaker is set in the wrong position.     - The speaker is placed in another room behind closed doors. noisy<Left/Right/External>Microphone:   When the recording of the given microphone is too noisy.   Could be because:     - Something is blocking the microphone externalMicrophoneLocation:   When the location of the external microphone is invalid. externalMicrophoneMissing:   If the external microphone was missing/disconnected during a measurement. microphonesDisabled:   If the microphones are either muted or disabled. noisyMeasurement:   When too much background noise has been detected during the measurement internalError:   Something went wrong internally - can not be fixed by the user. Try again.   # noqa: E501

        :return: The error of this RoomCompensationMeasurementError.  # noqa: E501
        :rtype: 'RoomCompensationMeasurementError.LTypeError'
        """
        return self._error

    @error.setter
    def error(self, error):
        # type: ('RoomCompensationMeasurementError.LTypeError') -> None
        """Sets the error of this RoomCompensationMeasurementError.

        noError:   The measurement went OK. lowSignal:   When there is too low signal in the recording, e.g. due to a loudspeaker being placed at   too great a distance from the microphone. speakerSilent:   No signal could be measured.   Could be because:     - The speaker is powered off or not connected.     - The left/right switch on a wired powerlink speaker is set in the wrong position.     - The speaker is placed in another room behind closed doors. noisy<Left/Right/External>Microphone:   When the recording of the given microphone is too noisy.   Could be because:     - Something is blocking the microphone externalMicrophoneLocation:   When the location of the external microphone is invalid. externalMicrophoneMissing:   If the external microphone was missing/disconnected during a measurement. microphonesDisabled:   If the microphones are either muted or disabled. noisyMeasurement:   When too much background noise has been detected during the measurement internalError:   Something went wrong internally - can not be fixed by the user. Try again.   # noqa: E501

        :param error: The error of this RoomCompensationMeasurementError.  # noqa: E501
        :type error: 'RoomCompensationMeasurementError.LTypeError'
        :rtype: None
        """
        allowed_values = [
            "noError",
            "lowSignal",
            "speakerSilent",
            "noisyLeftMicrophone",
            "noisyRightMicrophone",
            "noisyExternalMicrophone",
            "externalMicrophoneLocation",
            "externalMicrophoneMissing",
            "microphonesDisabled",
            "noisyMeasurement",
            "internalError",
        ]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and error not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `error` ({0}), must be one of {1}".format(  # noqa: E501
                    error, allowed_values
                )
            )

        self._error = error

    @property
    def speaker_id(self):
        # type: () -> str
        """Gets the speaker_id of this RoomCompensationMeasurementError.  # noqa: E501


        :return: The speaker_id of this RoomCompensationMeasurementError.  # noqa: E501
        :rtype: str
        """
        return self._speaker_id

    @speaker_id.setter
    def speaker_id(self, speaker_id):
        # type: (str) -> None
        """Sets the speaker_id of this RoomCompensationMeasurementError.


        :param speaker_id: The speaker_id of this RoomCompensationMeasurementError.  # noqa: E501
        :type speaker_id: str
        :rtype: None
        """

        self._speaker_id = speaker_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RoomCompensationMeasurementError):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RoomCompensationMeasurementError):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from mozart_api.api_client import ApiClient
from mozart_api.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class DeezerApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def start_deezer_flow(self, **kwargs):  # noqa: E501
        """Play users flow. If no provided user id it will play the flow connected to the active account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_deezer_flow(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserFlow user_flow: Select user
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        return self.start_deezer_flow_with_http_info(**kwargs)  # noqa: E501

    def start_deezer_flow_with_http_info(self, **kwargs):  # noqa: E501
        """Play users flow. If no provided user id it will play the flow connected to the active account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.start_deezer_flow_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UserFlow user_flow: Select user
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ["user_flow"]
        all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
            ]
        )

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method start_deezer_flow" % key
                )
            local_var_params[key] = val
        del local_var_params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "user_flow" in local_var_params:
            body_params = local_var_params["user_flow"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )  # noqa: E501

        # HTTP header `Content-Type`
        header_params[
            "Content-Type"
        ] = self.api_client.select_header_content_type(  # noqa: E501
            ["application/json"]
        )  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            "/api/v1/playback/deezer/flow",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get(
                "_return_http_data_only"
            ),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.action import Action

from mozart_api.configuration import Configuration


class Scene(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "action_list": "list[Action]",
        "client_context": "str",
        "label": "str",
        "tags": "list[str]",
        "classification": "str",
    }

    attribute_map = {
        "action_list": "actionList",
        "client_context": "clientContext",
        "label": "label",
        "tags": "tags",
        "classification": "classification",
    }

    def __init__(
        self,
        action_list: Optional[List[Action]] = None,
        client_context: Optional[str] = None,
        label: Optional[str] = None,
        tags: Optional[List[str]] = None,
        classification: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Scene - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_list = None
        self._client_context = None
        self._label = None
        self._tags = None
        self._classification = None
        self.discriminator = None

        self.action_list = action_list
        self.client_context = client_context
        self.label = label
        if tags is not None:
            self.tags = tags
        self.classification = classification

    @property
    def action_list(self):
        # type: () -> List[Action]
        """Gets the action_list of this Scene.  # noqa: E501

        An ordered list of Actions to run on the product  # noqa: E501

        :return: The action_list of this Scene.  # noqa: E501
        :rtype: List[Action]
        """
        return self._action_list

    @action_list.setter
    def action_list(self, action_list):
        # type: (list[Action]) -> None
        """Sets the action_list of this Scene.

        An ordered list of Actions to run on the product  # noqa: E501

        :param action_list: The action_list of this Scene.  # noqa: E501
        :type action_list: list[Action]
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and action_list is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `action_list`, must not be `None`"
            )  # noqa: E501

        self._action_list = action_list

    @property
    def client_context(self):
        # type: () -> str
        """Gets the client_context of this Scene.  # noqa: E501

        An optional generic string property supplied from the client. If supplied it will overwrite any currently stored clientContext. If not supplied any stored clientContext will be left unchanged.   # noqa: E501

        :return: The client_context of this Scene.  # noqa: E501
        :rtype: str
        """
        return self._client_context

    @client_context.setter
    def client_context(self, client_context):
        # type: (str) -> None
        """Sets the client_context of this Scene.

        An optional generic string property supplied from the client. If supplied it will overwrite any currently stored clientContext. If not supplied any stored clientContext will be left unchanged.   # noqa: E501

        :param client_context: The client_context of this Scene.  # noqa: E501
        :type client_context: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and client_context is not None
            and len(client_context) > 4096
        ):
            raise ValueError(
                "Invalid value for `client_context`, length must be less than or equal to `4096`"
            )  # noqa: E501

        self._client_context = client_context

    @property
    def label(self):
        # type: () -> str
        """Gets the label of this Scene.  # noqa: E501


        :return: The label of this Scene.  # noqa: E501
        :rtype: str
        """
        return self._label

    @label.setter
    def label(self, label):
        # type: (str) -> None
        """Sets the label of this Scene.


        :param label: The label of this Scene.  # noqa: E501
        :type label: str
        :rtype: None
        """

        self._label = label

    @property
    def tags(self):
        # type: () -> List[str]
        """Gets the tags of this Scene.  # noqa: E501

        A list of user defined tags. This allows a client to create virtual lists  # noqa: E501

        :return: The tags of this Scene.  # noqa: E501
        :rtype: List[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        # type: (list[str]) -> None
        """Sets the tags of this Scene.

        A list of user defined tags. This allows a client to create virtual lists  # noqa: E501

        :param tags: The tags of this Scene.  # noqa: E501
        :type tags: list[str]
        :rtype: None
        """

        self._tags = tags

    @property
    def classification(self):
        # type: () -> str
        """Gets the classification of this Scene.  # noqa: E501

        The classification of Scene  # noqa: E501

        :return: The classification of this Scene.  # noqa: E501
        :rtype: str
        """
        return self._classification

    @classification.setter
    def classification(self, classification):
        # type: (str) -> None
        """Sets the classification of this Scene.

        The classification of Scene  # noqa: E501

        :param classification: The classification of this Scene.  # noqa: E501
        :type classification: str
        :rtype: None
        """
        allowed_values = [None, "system", "userDefined"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and classification not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `classification` ({0}), must be one of {1}".format(  # noqa: E501
                    classification, allowed_values
                )
            )

        self._classification = classification

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Scene):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Scene):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.sound_adjustments import SoundAdjustments
from mozart_api.models.room_compensation_info import RoomCompensationInfo
from mozart_api.models.sound_tone_touch import SoundToneTouch

from mozart_api.configuration import Configuration


class SoundSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "adjustments": "SoundAdjustments",
        "room_compensation": "RoomCompensationInfo",
        "tone_touch": "SoundToneTouch",
    }

    attribute_map = {
        "adjustments": "adjustments",
        "room_compensation": "roomCompensation",
        "tone_touch": "toneTouch",
    }

    def __init__(
        self,
        adjustments: Optional[SoundAdjustments] = None,
        room_compensation: Optional[RoomCompensationInfo] = None,
        tone_touch: Optional[SoundToneTouch] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """SoundSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._adjustments = None
        self._room_compensation = None
        self._tone_touch = None
        self.discriminator = None

        if adjustments is not None:
            self.adjustments = adjustments
        if room_compensation is not None:
            self.room_compensation = room_compensation
        if tone_touch is not None:
            self.tone_touch = tone_touch

    @property
    def adjustments(self):
        # type: () -> SoundAdjustments
        """Gets the adjustments of this SoundSettings.  # noqa: E501


        :return: The adjustments of this SoundSettings.  # noqa: E501
        :rtype: SoundAdjustments
        """
        return self._adjustments

    @adjustments.setter
    def adjustments(self, adjustments):
        # type: (SoundAdjustments) -> None
        """Sets the adjustments of this SoundSettings.


        :param adjustments: The adjustments of this SoundSettings.  # noqa: E501
        :type adjustments: SoundAdjustments
        :rtype: None
        """

        self._adjustments = adjustments

    @property
    def room_compensation(self):
        # type: () -> RoomCompensationInfo
        """Gets the room_compensation of this SoundSettings.  # noqa: E501


        :return: The room_compensation of this SoundSettings.  # noqa: E501
        :rtype: RoomCompensationInfo
        """
        return self._room_compensation

    @room_compensation.setter
    def room_compensation(self, room_compensation):
        # type: (RoomCompensationInfo) -> None
        """Sets the room_compensation of this SoundSettings.


        :param room_compensation: The room_compensation of this SoundSettings.  # noqa: E501
        :type room_compensation: RoomCompensationInfo
        :rtype: None
        """

        self._room_compensation = room_compensation

    @property
    def tone_touch(self):
        # type: () -> SoundToneTouch
        """Gets the tone_touch of this SoundSettings.  # noqa: E501


        :return: The tone_touch of this SoundSettings.  # noqa: E501
        :rtype: SoundToneTouch
        """
        return self._tone_touch

    @tone_touch.setter
    def tone_touch(self, tone_touch):
        # type: (SoundToneTouch) -> None
        """Sets the tone_touch of this SoundSettings.


        :param tone_touch: The tone_touch of this SoundSettings.  # noqa: E501
        :type tone_touch: SoundToneTouch
        :rtype: None
        """

        self._tone_touch = tone_touch

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SoundSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SoundSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.content_item import ContentItem
from mozart_api.models.source_type_enum import SourceTypeEnum
from mozart_api.models.action import Action

from mozart_api.configuration import Configuration


class Preset(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "action_list": "list[Action]",
        "scene_list": "list[str]",
        "content": "ContentItem",
        "id": "str",
        "name": "str",
        "source": "SourceTypeEnum",
        "title": "str",
    }

    attribute_map = {
        "action_list": "actionList",
        "scene_list": "sceneList",
        "content": "content",
        "id": "id",
        "name": "name",
        "source": "source",
        "title": "title",
    }

    def __init__(
        self,
        action_list: Optional[List[Action]] = None,
        scene_list: Optional[List[str]] = None,
        content: Optional[ContentItem] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        source: Optional[SourceTypeEnum] = None,
        title: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """Preset - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._action_list = None
        self._scene_list = None
        self._content = None
        self._id = None
        self._name = None
        self._source = None
        self._title = None
        self.discriminator = None

        if action_list is not None:
            self.action_list = action_list
        if scene_list is not None:
            self.scene_list = scene_list
        if content is not None:
            self.content = content
        if id is not None:
            self.id = id
        self.name = name
        if source is not None:
            self.source = source
        if title is not None:
            self.title = title

    @property
    def action_list(self):
        # type: () -> List[Action]
        """Gets the action_list of this Preset.  # noqa: E501

        An ordered list of Actions to run on the product  # noqa: E501

        :return: The action_list of this Preset.  # noqa: E501
        :rtype: List[Action]
        """
        return self._action_list

    @action_list.setter
    def action_list(self, action_list):
        # type: (list[Action]) -> None
        """Sets the action_list of this Preset.

        An ordered list of Actions to run on the product  # noqa: E501

        :param action_list: The action_list of this Preset.  # noqa: E501
        :type action_list: list[Action]
        :rtype: None
        """

        self._action_list = action_list

    @property
    def scene_list(self):
        # type: () -> List[str]
        """Gets the scene_list of this Preset.  # noqa: E501

        A list of scenes  # noqa: E501

        :return: The scene_list of this Preset.  # noqa: E501
        :rtype: List[str]
        """
        return self._scene_list

    @scene_list.setter
    def scene_list(self, scene_list):
        # type: (list[str]) -> None
        """Sets the scene_list of this Preset.

        A list of scenes  # noqa: E501

        :param scene_list: The scene_list of this Preset.  # noqa: E501
        :type scene_list: list[str]
        :rtype: None
        """

        self._scene_list = scene_list

    @property
    def content(self):
        # type: () -> ContentItem
        """Gets the content of this Preset.  # noqa: E501


        :return: The content of this Preset.  # noqa: E501
        :rtype: ContentItem
        """
        return self._content

    @content.setter
    def content(self, content):
        # type: (ContentItem) -> None
        """Sets the content of this Preset.


        :param content: The content of this Preset.  # noqa: E501
        :type content: ContentItem
        :rtype: None
        """

        self._content = content

    @property
    def id(self):
        # type: () -> str
        """Gets the id of this Preset.  # noqa: E501


        :return: The id of this Preset.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        # type: (str) -> None
        """Sets the id of this Preset.


        :param id: The id of this Preset.  # noqa: E501
        :type id: str
        :rtype: None
        """

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this Preset.  # noqa: E501


        :return: The name of this Preset.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (str) -> None
        """Sets the name of this Preset.


        :param name: The name of this Preset.  # noqa: E501
        :type name: str
        :rtype: None
        """

        self._name = name

    @property
    def source(self):
        # type: () -> SourceTypeEnum
        """Gets the source of this Preset.  # noqa: E501


        :return: The source of this Preset.  # noqa: E501
        :rtype: SourceTypeEnum
        """
        return self._source

    @source.setter
    def source(self, source):
        # type: (SourceTypeEnum) -> None
        """Sets the source of this Preset.


        :param source: The source of this Preset.  # noqa: E501
        :type source: SourceTypeEnum
        :rtype: None
        """

        self._source = source

    @property
    def title(self):
        # type: () -> str
        """Gets the title of this Preset.  # noqa: E501


        :return: The title of this Preset.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        # type: (str) -> None
        """Sets the title of this Preset.


        :param title: The title of this Preset.  # noqa: E501
        :type title: str
        :rtype: None
        """

        self._title = title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Preset):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Preset):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from mozart_api.api.beolink_api import BeolinkApi
from mozart_api.api.bluetooth_api import BluetoothApi
from mozart_api.api.content_api import ContentApi
from mozart_api.api.deezer_api import DeezerApi
from mozart_api.api.overlay_api import OverlayApi
from mozart_api.api.playback_api import PlaybackApi
from mozart_api.api.power_api import PowerApi
from mozart_api.api.product_api import ProductApi
from mozart_api.api.remote_api import RemoteApi
from mozart_api.api.scenes_api import ScenesApi
from mozart_api.api.settings_api import SettingsApi
from mozart_api.api.software_update_api import SoftwareUpdateApi
from mozart_api.api.sound_api import SoundApi
from mozart_api.api.speaker_group_api import SpeakerGroupApi
from mozart_api.api.mozart_api import MozartApi



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.listening_mode_features import ListeningModeFeatures
from mozart_api.models.listening_mode_trigger import ListeningModeTrigger

from mozart_api.configuration import Configuration


class ListeningModeProps(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "client_ctx": "str",
        "features": "ListeningModeFeatures",
        "id": "int",
        "name": "str",
        "origin": "str",
        "role": "str",
        "triggers": "list[ListeningModeTrigger]",
    }

    attribute_map = {
        "client_ctx": "clientCtx",
        "features": "features",
        "id": "id",
        "name": "name",
        "origin": "origin",
        "role": "role",
        "triggers": "triggers",
    }

    def __init__(
        self,
        client_ctx: Optional[str] = None,
        features: Optional[ListeningModeFeatures] = None,
        id: Optional[int] = None,
        name: Optional[str] = None,
        origin: Optional["ListeningModeProps.LTypeOrigin"] = None,
        role: Optional["ListeningModeProps.LTypeRole"] = None,
        triggers: Optional[List[ListeningModeTrigger]] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ListeningModeProps - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._client_ctx = None
        self._features = None
        self._id = None
        self._name = None
        self._origin = None
        self._role = None
        self._triggers = None
        self.discriminator = None

        self.client_ctx = client_ctx
        if features is not None:
            self.features = features
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        if origin is not None:
            self.origin = origin
        if role is not None:
            self.role = role
        if triggers is not None:
            self.triggers = triggers

    @property
    def client_ctx(self):
        # type: () -> str
        """Gets the client_ctx of this ListeningModeProps.  # noqa: E501

        An optional generic string property supplied from the client. If provided, it will be stored without changes. If not supplied, any current clientCtx will remain unchanged.   # noqa: E501

        :return: The client_ctx of this ListeningModeProps.  # noqa: E501
        :rtype: str
        """
        return self._client_ctx

    @client_ctx.setter
    def client_ctx(self, client_ctx):
        # type: (str) -> None
        """Sets the client_ctx of this ListeningModeProps.

        An optional generic string property supplied from the client. If provided, it will be stored without changes. If not supplied, any current clientCtx will remain unchanged.   # noqa: E501

        :param client_ctx: The client_ctx of this ListeningModeProps.  # noqa: E501
        :type client_ctx: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and client_ctx is not None
            and len(client_ctx) > 4096
        ):
            raise ValueError(
                "Invalid value for `client_ctx`, length must be less than or equal to `4096`"
            )  # noqa: E501

        self._client_ctx = client_ctx

    @property
    def features(self):
        # type: () -> ListeningModeFeatures
        """Gets the features of this ListeningModeProps.  # noqa: E501


        :return: The features of this ListeningModeProps.  # noqa: E501
        :rtype: ListeningModeFeatures
        """
        return self._features

    @features.setter
    def features(self, features):
        # type: (ListeningModeFeatures) -> None
        """Sets the features of this ListeningModeProps.


        :param features: The features of this ListeningModeProps.  # noqa: E501
        :type features: ListeningModeFeatures
        :rtype: None
        """

        self._features = features

    @property
    def id(self):
        # type: () -> int
        """Gets the id of this ListeningModeProps.  # noqa: E501


        :return: The id of this ListeningModeProps.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        # type: (int) -> None
        """Sets the id of this ListeningModeProps.


        :param id: The id of this ListeningModeProps.  # noqa: E501
        :type id: int
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation
            and id is not None
            and id < 0
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `id`, must be a value greater than or equal to `0`"
            )  # noqa: E501

        self._id = id

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this ListeningModeProps.  # noqa: E501

        Friendly name  # noqa: E501

        :return: The name of this ListeningModeProps.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        # type: (str) -> None
        """Sets the name of this ListeningModeProps.

        Friendly name  # noqa: E501

        :param name: The name of this ListeningModeProps.  # noqa: E501
        :type name: str
        :rtype: None
        """

        self._name = name

    LTypeOrigin = Literal["user", "default", "edited"]

    @property
    def origin(self):
        # type: () -> 'ListeningModeProps.LTypeOrigin'
        """Gets the origin of this ListeningModeProps.  # noqa: E501

        User created, default or an edited default listening mode  # noqa: E501

        :return: The origin of this ListeningModeProps.  # noqa: E501
        :rtype: 'ListeningModeProps.LTypeOrigin'
        """
        return self._origin

    @origin.setter
    def origin(self, origin):
        # type: ('ListeningModeProps.LTypeOrigin') -> None
        """Sets the origin of this ListeningModeProps.

        User created, default or an edited default listening mode  # noqa: E501

        :param origin: The origin of this ListeningModeProps.  # noqa: E501
        :type origin: 'ListeningModeProps.LTypeOrigin'
        :rtype: None
        """
        allowed_values = ["user", "default", "edited"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and origin not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `origin` ({0}), must be one of {1}".format(  # noqa: E501
                    origin, allowed_values
                )
            )

        self._origin = origin

    LTypeRole = Literal["standalone", "multichannel"]

    @property
    def role(self):
        # type: () -> 'ListeningModeProps.LTypeRole'
        """Gets the role of this ListeningModeProps.  # noqa: E501

        Role a listening mode applies to  # noqa: E501

        :return: The role of this ListeningModeProps.  # noqa: E501
        :rtype: 'ListeningModeProps.LTypeRole'
        """
        return self._role

    @role.setter
    def role(self, role):
        # type: ('ListeningModeProps.LTypeRole') -> None
        """Sets the role of this ListeningModeProps.

        Role a listening mode applies to  # noqa: E501

        :param role: The role of this ListeningModeProps.  # noqa: E501
        :type role: 'ListeningModeProps.LTypeRole'
        :rtype: None
        """
        allowed_values = ["standalone", "multichannel"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and role not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `role` ({0}), must be one of {1}".format(  # noqa: E501
                    role, allowed_values
                )
            )

        self._role = role

    @property
    def triggers(self):
        # type: () -> List[ListeningModeTrigger]
        """Gets the triggers of this ListeningModeProps.  # noqa: E501


        :return: The triggers of this ListeningModeProps.  # noqa: E501
        :rtype: List[ListeningModeTrigger]
        """
        return self._triggers

    @triggers.setter
    def triggers(self, triggers):
        # type: (list[ListeningModeTrigger]) -> None
        """Sets the triggers of this ListeningModeProps.


        :param triggers: The triggers of this ListeningModeProps.  # noqa: E501
        :type triggers: list[ListeningModeTrigger]
        :rtype: None
        """

        self._triggers = triggers

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListeningModeProps):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListeningModeProps):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.room_compensation import RoomCompensation
from mozart_api.models.speech_enhance import SpeechEnhance
from mozart_api.models.fader import Fader
from mozart_api.models.spatial_height import SpatialHeight
from mozart_api.models.spatial_processing import SpatialProcessing
from mozart_api.models.spatial_surround import SpatialSurround
from mozart_api.models.balance import Balance
from mozart_api.models.directivity import Directivity
from mozart_api.models.compression import Compression
from mozart_api.models.tone_touch import ToneTouch
from mozart_api.models.spatial_envelopment import SpatialEnvelopment
from mozart_api.models.ambience import Ambience
from mozart_api.models.spatial_width import SpatialWidth
from mozart_api.models.bass_management import BassManagement

from mozart_api.configuration import Configuration


class ListeningModeFeatures(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "ambience": "Ambience",
        "balance": "Balance",
        "bass_management": "BassManagement",
        "compression": "Compression",
        "directivity": "Directivity",
        "fader": "Fader",
        "room_compensation": "RoomCompensation",
        "spatial_envelopment": "SpatialEnvelopment",
        "spatial_height": "SpatialHeight",
        "spatial_processing": "SpatialProcessing",
        "spatial_surround": "SpatialSurround",
        "spatial_width": "SpatialWidth",
        "speech_enhance": "SpeechEnhance",
        "tone_touch": "ToneTouch",
    }

    attribute_map = {
        "ambience": "ambience",
        "balance": "balance",
        "bass_management": "bassManagement",
        "compression": "compression",
        "directivity": "directivity",
        "fader": "fader",
        "room_compensation": "roomCompensation",
        "spatial_envelopment": "spatialEnvelopment",
        "spatial_height": "spatialHeight",
        "spatial_processing": "spatialProcessing",
        "spatial_surround": "spatialSurround",
        "spatial_width": "spatialWidth",
        "speech_enhance": "speechEnhance",
        "tone_touch": "toneTouch",
    }

    def __init__(
        self,
        ambience: Optional[Ambience] = None,
        balance: Optional[Balance] = None,
        bass_management: Optional[BassManagement] = None,
        compression: Optional[Compression] = None,
        directivity: Optional[Directivity] = None,
        fader: Optional[Fader] = None,
        room_compensation: Optional[RoomCompensation] = None,
        spatial_envelopment: Optional[SpatialEnvelopment] = None,
        spatial_height: Optional[SpatialHeight] = None,
        spatial_processing: Optional[SpatialProcessing] = None,
        spatial_surround: Optional[SpatialSurround] = None,
        spatial_width: Optional[SpatialWidth] = None,
        speech_enhance: Optional[SpeechEnhance] = None,
        tone_touch: Optional[ToneTouch] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """ListeningModeFeatures - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ambience = None
        self._balance = None
        self._bass_management = None
        self._compression = None
        self._directivity = None
        self._fader = None
        self._room_compensation = None
        self._spatial_envelopment = None
        self._spatial_height = None
        self._spatial_processing = None
        self._spatial_surround = None
        self._spatial_width = None
        self._speech_enhance = None
        self._tone_touch = None
        self.discriminator = None

        if ambience is not None:
            self.ambience = ambience
        if balance is not None:
            self.balance = balance
        if bass_management is not None:
            self.bass_management = bass_management
        if compression is not None:
            self.compression = compression
        if directivity is not None:
            self.directivity = directivity
        if fader is not None:
            self.fader = fader
        if room_compensation is not None:
            self.room_compensation = room_compensation
        if spatial_envelopment is not None:
            self.spatial_envelopment = spatial_envelopment
        if spatial_height is not None:
            self.spatial_height = spatial_height
        if spatial_processing is not None:
            self.spatial_processing = spatial_processing
        if spatial_surround is not None:
            self.spatial_surround = spatial_surround
        if spatial_width is not None:
            self.spatial_width = spatial_width
        if speech_enhance is not None:
            self.speech_enhance = speech_enhance
        if tone_touch is not None:
            self.tone_touch = tone_touch

    @property
    def ambience(self):
        # type: () -> Ambience
        """Gets the ambience of this ListeningModeFeatures.  # noqa: E501


        :return: The ambience of this ListeningModeFeatures.  # noqa: E501
        :rtype: Ambience
        """
        return self._ambience

    @ambience.setter
    def ambience(self, ambience):
        # type: (Ambience) -> None
        """Sets the ambience of this ListeningModeFeatures.


        :param ambience: The ambience of this ListeningModeFeatures.  # noqa: E501
        :type ambience: Ambience
        :rtype: None
        """

        self._ambience = ambience

    @property
    def balance(self):
        # type: () -> Balance
        """Gets the balance of this ListeningModeFeatures.  # noqa: E501


        :return: The balance of this ListeningModeFeatures.  # noqa: E501
        :rtype: Balance
        """
        return self._balance

    @balance.setter
    def balance(self, balance):
        # type: (Balance) -> None
        """Sets the balance of this ListeningModeFeatures.


        :param balance: The balance of this ListeningModeFeatures.  # noqa: E501
        :type balance: Balance
        :rtype: None
        """

        self._balance = balance

    @property
    def bass_management(self):
        # type: () -> BassManagement
        """Gets the bass_management of this ListeningModeFeatures.  # noqa: E501


        :return: The bass_management of this ListeningModeFeatures.  # noqa: E501
        :rtype: BassManagement
        """
        return self._bass_management

    @bass_management.setter
    def bass_management(self, bass_management):
        # type: (BassManagement) -> None
        """Sets the bass_management of this ListeningModeFeatures.


        :param bass_management: The bass_management of this ListeningModeFeatures.  # noqa: E501
        :type bass_management: BassManagement
        :rtype: None
        """

        self._bass_management = bass_management

    @property
    def compression(self):
        # type: () -> Compression
        """Gets the compression of this ListeningModeFeatures.  # noqa: E501


        :return: The compression of this ListeningModeFeatures.  # noqa: E501
        :rtype: Compression
        """
        return self._compression

    @compression.setter
    def compression(self, compression):
        # type: (Compression) -> None
        """Sets the compression of this ListeningModeFeatures.


        :param compression: The compression of this ListeningModeFeatures.  # noqa: E501
        :type compression: Compression
        :rtype: None
        """

        self._compression = compression

    @property
    def directivity(self):
        # type: () -> Directivity
        """Gets the directivity of this ListeningModeFeatures.  # noqa: E501


        :return: The directivity of this ListeningModeFeatures.  # noqa: E501
        :rtype: Directivity
        """
        return self._directivity

    @directivity.setter
    def directivity(self, directivity):
        # type: (Directivity) -> None
        """Sets the directivity of this ListeningModeFeatures.


        :param directivity: The directivity of this ListeningModeFeatures.  # noqa: E501
        :type directivity: Directivity
        :rtype: None
        """

        self._directivity = directivity

    @property
    def fader(self):
        # type: () -> Fader
        """Gets the fader of this ListeningModeFeatures.  # noqa: E501


        :return: The fader of this ListeningModeFeatures.  # noqa: E501
        :rtype: Fader
        """
        return self._fader

    @fader.setter
    def fader(self, fader):
        # type: (Fader) -> None
        """Sets the fader of this ListeningModeFeatures.


        :param fader: The fader of this ListeningModeFeatures.  # noqa: E501
        :type fader: Fader
        :rtype: None
        """

        self._fader = fader

    @property
    def room_compensation(self):
        # type: () -> RoomCompensation
        """Gets the room_compensation of this ListeningModeFeatures.  # noqa: E501


        :return: The room_compensation of this ListeningModeFeatures.  # noqa: E501
        :rtype: RoomCompensation
        """
        return self._room_compensation

    @room_compensation.setter
    def room_compensation(self, room_compensation):
        # type: (RoomCompensation) -> None
        """Sets the room_compensation of this ListeningModeFeatures.


        :param room_compensation: The room_compensation of this ListeningModeFeatures.  # noqa: E501
        :type room_compensation: RoomCompensation
        :rtype: None
        """

        self._room_compensation = room_compensation

    @property
    def spatial_envelopment(self):
        # type: () -> SpatialEnvelopment
        """Gets the spatial_envelopment of this ListeningModeFeatures.  # noqa: E501


        :return: The spatial_envelopment of this ListeningModeFeatures.  # noqa: E501
        :rtype: SpatialEnvelopment
        """
        return self._spatial_envelopment

    @spatial_envelopment.setter
    def spatial_envelopment(self, spatial_envelopment):
        # type: (SpatialEnvelopment) -> None
        """Sets the spatial_envelopment of this ListeningModeFeatures.


        :param spatial_envelopment: The spatial_envelopment of this ListeningModeFeatures.  # noqa: E501
        :type spatial_envelopment: SpatialEnvelopment
        :rtype: None
        """

        self._spatial_envelopment = spatial_envelopment

    @property
    def spatial_height(self):
        # type: () -> SpatialHeight
        """Gets the spatial_height of this ListeningModeFeatures.  # noqa: E501


        :return: The spatial_height of this ListeningModeFeatures.  # noqa: E501
        :rtype: SpatialHeight
        """
        return self._spatial_height

    @spatial_height.setter
    def spatial_height(self, spatial_height):
        # type: (SpatialHeight) -> None
        """Sets the spatial_height of this ListeningModeFeatures.


        :param spatial_height: The spatial_height of this ListeningModeFeatures.  # noqa: E501
        :type spatial_height: SpatialHeight
        :rtype: None
        """

        self._spatial_height = spatial_height

    @property
    def spatial_processing(self):
        # type: () -> SpatialProcessing
        """Gets the spatial_processing of this ListeningModeFeatures.  # noqa: E501


        :return: The spatial_processing of this ListeningModeFeatures.  # noqa: E501
        :rtype: SpatialProcessing
        """
        return self._spatial_processing

    @spatial_processing.setter
    def spatial_processing(self, spatial_processing):
        # type: (SpatialProcessing) -> None
        """Sets the spatial_processing of this ListeningModeFeatures.


        :param spatial_processing: The spatial_processing of this ListeningModeFeatures.  # noqa: E501
        :type spatial_processing: SpatialProcessing
        :rtype: None
        """

        self._spatial_processing = spatial_processing

    @property
    def spatial_surround(self):
        # type: () -> SpatialSurround
        """Gets the spatial_surround of this ListeningModeFeatures.  # noqa: E501


        :return: The spatial_surround of this ListeningModeFeatures.  # noqa: E501
        :rtype: SpatialSurround
        """
        return self._spatial_surround

    @spatial_surround.setter
    def spatial_surround(self, spatial_surround):
        # type: (SpatialSurround) -> None
        """Sets the spatial_surround of this ListeningModeFeatures.


        :param spatial_surround: The spatial_surround of this ListeningModeFeatures.  # noqa: E501
        :type spatial_surround: SpatialSurround
        :rtype: None
        """

        self._spatial_surround = spatial_surround

    @property
    def spatial_width(self):
        # type: () -> SpatialWidth
        """Gets the spatial_width of this ListeningModeFeatures.  # noqa: E501


        :return: The spatial_width of this ListeningModeFeatures.  # noqa: E501
        :rtype: SpatialWidth
        """
        return self._spatial_width

    @spatial_width.setter
    def spatial_width(self, spatial_width):
        # type: (SpatialWidth) -> None
        """Sets the spatial_width of this ListeningModeFeatures.


        :param spatial_width: The spatial_width of this ListeningModeFeatures.  # noqa: E501
        :type spatial_width: SpatialWidth
        :rtype: None
        """

        self._spatial_width = spatial_width

    @property
    def speech_enhance(self):
        # type: () -> SpeechEnhance
        """Gets the speech_enhance of this ListeningModeFeatures.  # noqa: E501


        :return: The speech_enhance of this ListeningModeFeatures.  # noqa: E501
        :rtype: SpeechEnhance
        """
        return self._speech_enhance

    @speech_enhance.setter
    def speech_enhance(self, speech_enhance):
        # type: (SpeechEnhance) -> None
        """Sets the speech_enhance of this ListeningModeFeatures.


        :param speech_enhance: The speech_enhance of this ListeningModeFeatures.  # noqa: E501
        :type speech_enhance: SpeechEnhance
        :rtype: None
        """

        self._speech_enhance = speech_enhance

    @property
    def tone_touch(self):
        # type: () -> ToneTouch
        """Gets the tone_touch of this ListeningModeFeatures.  # noqa: E501


        :return: The tone_touch of this ListeningModeFeatures.  # noqa: E501
        :rtype: ToneTouch
        """
        return self._tone_touch

    @tone_touch.setter
    def tone_touch(self, tone_touch):
        # type: (ToneTouch) -> None
        """Sets the tone_touch of this ListeningModeFeatures.


        :param tone_touch: The tone_touch of this ListeningModeFeatures.  # noqa: E501
        :type tone_touch: ToneTouch
        :rtype: None
        """

        self._tone_touch = tone_touch

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListeningModeFeatures):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ListeningModeFeatures):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.web_socket_event_playback_error import (
    WebSocketEventPlaybackError,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestWebSocketEventPlaybackError(unittest.TestCase):
    """WebSocketEventPlaybackError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebSocketEventPlaybackError
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.web_socket_event_playback_error.WebSocketEventPlaybackError()  # noqa: E501
        if include_optional:
            return WebSocketEventPlaybackError(
                event_data=mozart_api.models.playback_error.PlaybackError(
                    error="0",
                    item=mozart_api.models.playback_content_metadata.PlaybackContentMetadata(
                        album_name="0",
                        art=[
                            mozart_api.models.art.Art(
                                has_local_image=True,
                                key="0",
                                size="0",
                                type="0",
                                url="0",
                            )
                        ],
                        artist_name="0",
                        bitdepth=56,
                        bitrate=56,
                        container_name="0",
                        encoding="pcm",
                        genre="0",
                        id=56,
                        input_channel_processing="dolbySurround",
                        input_channels="0",
                        organization="0",
                        output_channel_processing="Direct",
                        output_channels="0",
                        queue_id="0",
                        remote_leader=mozart_api.models.beolink_leader.BeolinkLeader(
                            friendly_name="0",
                            jid="2714.1200304.26451293@products.bang-olufsen.com",
                        ),
                        remote_source="0",
                        samplerate=56,
                        source="0",
                        source_internal_id="0",
                        title="0",
                        total_duration=56,
                        total_duration_seconds=56,
                        track=56,
                        track_count=56,
                        uri="0",
                    ),
                ),
                event_type="0",
            )
        else:
            return WebSocketEventPlaybackError()

    def testWebSocketEventPlaybackError(self):
        """Test WebSocketEventPlaybackError"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from datetime import datetime
from typing import List, Dict, Literal, Optional

from mozart_api.models.playback_content_metadata import PlaybackContentMetadata
from mozart_api.models.play_queue_item_type import PlayQueueItemType

from mozart_api.configuration import Configuration


class PlayQueueItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "index": "int",
        "metadata": "PlaybackContentMetadata",
        "provider": "PlayQueueItemType",
        "start_now_from_position": "int",
        "type": "str",
        "uri": "str",
    }

    attribute_map = {
        "index": "index",
        "metadata": "metadata",
        "provider": "provider",
        "start_now_from_position": "startNowFromPosition",
        "type": "type",
        "uri": "uri",
    }

    def __init__(
        self,
        index: Optional[int] = None,
        metadata: Optional[PlaybackContentMetadata] = None,
        provider: Optional[PlayQueueItemType] = None,
        start_now_from_position: Optional[int] = None,
        type: Optional["PlayQueueItem.LTypeType"] = None,
        uri: Optional[str] = None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PlayQueueItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._metadata = None
        self._provider = None
        self._start_now_from_position = None
        self._type = None
        self._uri = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if metadata is not None:
            self.metadata = metadata
        self.provider = provider
        self.start_now_from_position = start_now_from_position
        self.type = type
        self.uri = uri

    @property
    def index(self):
        # type: () -> int
        """Gets the index of this PlayQueueItem.  # noqa: E501


        :return: The index of this PlayQueueItem.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        # type: (int) -> None
        """Sets the index of this PlayQueueItem.


        :param index: The index of this PlayQueueItem.  # noqa: E501
        :type index: int
        :rtype: None
        """

        self._index = index

    @property
    def metadata(self):
        # type: () -> PlaybackContentMetadata
        """Gets the metadata of this PlayQueueItem.  # noqa: E501


        :return: The metadata of this PlayQueueItem.  # noqa: E501
        :rtype: PlaybackContentMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        # type: (PlaybackContentMetadata) -> None
        """Sets the metadata of this PlayQueueItem.


        :param metadata: The metadata of this PlayQueueItem.  # noqa: E501
        :type metadata: PlaybackContentMetadata
        :rtype: None
        """

        self._metadata = metadata

    @property
    def provider(self):
        # type: () -> PlayQueueItemType
        """Gets the provider of this PlayQueueItem.  # noqa: E501


        :return: The provider of this PlayQueueItem.  # noqa: E501
        :rtype: PlayQueueItemType
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        # type: (PlayQueueItemType) -> None
        """Sets the provider of this PlayQueueItem.


        :param provider: The provider of this PlayQueueItem.  # noqa: E501
        :type provider: PlayQueueItemType
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and provider is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `provider`, must not be `None`"
            )  # noqa: E501

        self._provider = provider

    @property
    def start_now_from_position(self):
        # type: () -> int
        """Gets the start_now_from_position of this PlayQueueItem.  # noqa: E501

        Start playing specified track as soon as possible. This works for any type, for `track` set to 0 and for `playlist` specify the wanted track from position 0  # noqa: E501

        :return: The start_now_from_position of this PlayQueueItem.  # noqa: E501
        :rtype: int
        """
        return self._start_now_from_position

    @start_now_from_position.setter
    def start_now_from_position(self, start_now_from_position):
        # type: (int) -> None
        """Sets the start_now_from_position of this PlayQueueItem.

        Start playing specified track as soon as possible. This works for any type, for `track` set to 0 and for `playlist` specify the wanted track from position 0  # noqa: E501

        :param start_now_from_position: The start_now_from_position of this PlayQueueItem.  # noqa: E501
        :type start_now_from_position: int
        :rtype: None
        """

        self._start_now_from_position = start_now_from_position

    LTypeType = Literal["track", "playlist"]

    @property
    def type(self):
        # type: () -> 'PlayQueueItem.LTypeType'
        """Gets the type of this PlayQueueItem.  # noqa: E501


        :return: The type of this PlayQueueItem.  # noqa: E501
        :rtype: 'PlayQueueItem.LTypeType'
        """
        return self._type

    @type.setter
    def type(self, type):
        # type: ('PlayQueueItem.LTypeType') -> None
        """Sets the type of this PlayQueueItem.


        :param type: The type of this PlayQueueItem.  # noqa: E501
        :type type: 'PlayQueueItem.LTypeType'
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and type is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type`, must not be `None`"
            )  # noqa: E501
        allowed_values = ["track", "playlist"]  # noqa: E501
        if (
            self.local_vars_configuration.client_side_validation
            and type not in allowed_values
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}".format(  # noqa: E501
                    type, allowed_values
                )
            )

        self._type = type

    @property
    def uri(self):
        # type: () -> str
        """Gets the uri of this PlayQueueItem.  # noqa: E501

        This can be url, track id, playlist id, radio id and suchlike  # noqa: E501

        :return: The uri of this PlayQueueItem.  # noqa: E501
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        # type: (str) -> None
        """Sets the uri of this PlayQueueItem.

        This can be url, track id, playlist id, radio id and suchlike  # noqa: E501

        :param uri: The uri of this PlayQueueItem.  # noqa: E501
        :type uri: str
        :rtype: None
        """
        if (
            self.local_vars_configuration.client_side_validation and uri is None
        ):  # noqa: E501
            raise ValueError(
                "Invalid value for `uri`, must not be `None`"
            )  # noqa: E501

        self._uri = uri

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PlayQueueItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PlayQueueItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.sound_api import SoundApi  # noqa: E501
from mozart_api.rest import ApiException


class TestSoundApi(unittest.TestCase):
    """SoundApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.sound_api.SoundApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_listening_mode(self):
        """Test case for activate_listening_mode

        Activate a listening mode  # noqa: E501
        """
        pass

    def test_get_active_listening_mode(self):
        """Test case for get_active_listening_mode

        Get the active listening mode  # noqa: E501
        """
        pass

    def test_get_current_volume(self):
        """Test case for get_current_volume

        Get the current volume state  # noqa: E501
        """
        pass

    def test_get_listening_mode_set(self):
        """Test case for get_listening_mode_set

        Get available listening modes that match the current role (standalone or multichannel).   # noqa: E501
        """
        pass

    def test_get_sound_features(self):
        """Test case for get_sound_features

        Get available sound features that match the current role (standalone or multichannel).   # noqa: E501
        """
        pass

    def test_get_volume_settings(self):
        """Test case for get_volume_settings

        Get the current volume settings for default and maximum volume level  # noqa: E501
        """
        pass

    def test_set_current_volume_level(self):
        """Test case for set_current_volume_level

        Set the current volume level  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_bass(self):
        """Test case for set_sound_settings_adjustments_bass

        Update the sound settings adjustments for bass  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_directivity(self):
        """Test case for set_sound_settings_adjustments_directivity

        Update the sound settings adjustments for directivity  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_loudness(self):
        """Test case for set_sound_settings_adjustments_loudness

        Update the sound settings adjustments for loudness  # noqa: E501
        """
        pass

    def test_set_sound_settings_adjustments_treble(self):
        """Test case for set_sound_settings_adjustments_treble

        Update the sound settings adjustments for treble  # noqa: E501
        """
        pass

    def test_set_volume_mute(self):
        """Test case for set_volume_mute

        Set the volume mute state  # noqa: E501
        """
        pass

    def test_set_volume_settings(self):
        """Test case for set_volume_settings

        Set the current volume settings for default and maximum volume level  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.product_state import ProductState  # noqa: E501
from mozart_api.rest import ApiException


class TestProductState(unittest.TestCase):
    """ProductState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ProductState
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.product_state.ProductState()  # noqa: E501
        if include_optional:
            return ProductState(
                microphones=mozart_api.models.microphones_state.MicrophonesState(
                    microphone_state=mozart_api.models.microphone_state.MicrophoneState(
                        value="on",
                    ),
                    microphone_switch_state=mozart_api.models.microphone_state.MicrophoneState(
                        value="on",
                    ),
                ),
                playback=mozart_api.models.playback_state.PlaybackState(
                    metadata=mozart_api.models.playback_content_metadata.PlaybackContentMetadata(
                        album_name="0",
                        art=[
                            mozart_api.models.art.Art(
                                has_local_image=True,
                                key="0",
                                size="0",
                                type="0",
                                url="0",
                            )
                        ],
                        artist_name="0",
                        bitdepth=56,
                        bitrate=56,
                        container_name="0",
                        encoding="pcm",
                        genre="0",
                        id=56,
                        input_channel_processing="dolbySurround",
                        input_channels="0",
                        organization="0",
                        output_channel_processing="Direct",
                        output_channels="0",
                        queue_id="0",
                        remote_leader=mozart_api.models.beolink_leader.BeolinkLeader(
                            friendly_name="0",
                            jid="2714.1200304.26451293@products.bang-olufsen.com",
                        ),
                        remote_source="0",
                        samplerate=56,
                        source="0",
                        source_internal_id="0",
                        title="0",
                        total_duration=56,
                        total_duration_seconds=56,
                        track=56,
                        track_count=56,
                        uri="0",
                    ),
                    progress=mozart_api.models.playback_progress.PlaybackProgress(
                        id="0",
                        total_duration=56,
                    ),
                    source=mozart_api.models.source.Source(
                        id="0",
                        is_enabled=True,
                        is_playable=True,
                        name="0",
                        type=mozart_api.models.source_type_enum.SourceTypeEnum(
                            value="beolink",
                        ),
                    ),
                    state=mozart_api.models.rendering_state.RenderingState(
                        value="idle",
                    ),
                ),
                power_state=mozart_api.models.power_state_enum.PowerStateEnum(
                    value="networkStandby",
                ),
                software_update_state=mozart_api.models.software_update_state.SoftwareUpdateState(
                    seconds_remaining=56,
                    value="idle",
                ),
                sound_settings=mozart_api.models.sound_settings.SoundSettings(
                    adjustments=mozart_api.models.sound_adjustments.SoundAdjustments(
                        ambience=1.337,
                        bass=56,
                        directivity="0",
                        eco_mode=True,
                        fadein=True,
                        loudness=True,
                        treble=56,
                    ),
                    room_compensation=mozart_api.models.room_compensation_info.RoomCompensationInfo(
                        debug=mozart_api.models.room_compensation_debug.RoomCompensationDebug(
                            value=True,
                        ),
                        enabled=mozart_api.models.room_compensation_enabled.RoomCompensationEnabled(
                            value=True,
                        ),
                        last_result=mozart_api.models.room_compensation_result.RoomCompensationResult(
                            compensation=[
                                mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                    frequency=56,
                                    gain=1.337,
                                )
                            ],
                            measured_response=[
                                mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                    frequency=56,
                                    gain=1.337,
                                )
                            ],
                            placement="free",
                            reference_response=[
                                mozart_api.models.room_compensation_response.RoomCompensationResponse(
                                    frequency=56,
                                    gain=1.337,
                                )
                            ],
                            speaker_group_suggestion=mozart_api.models.speaker_group.SpeakerGroup(
                                crossover_frequency=20,
                                enable_phase_compensation=True,
                                friendly_name="0",
                                id="0",
                                is_deleteable=True,
                                items=[
                                    mozart_api.models.speaker_group_member.SpeakerGroupMember(
                                        distance=0,
                                        friendly_name="0",
                                        gain=-24,
                                        id="0",
                                        location=mozart_api.models.speaker_group_member_location.SpeakerGroupMember_location(
                                            x=56,
                                            y=56,
                                            z=56,
                                        ),
                                        redirection_level=-100,
                                        role="0",
                                        type="0",
                                    )
                                ],
                                room_compensation_id="0",
                                speaker_preset=0,
                            ),
                            time_stamp=datetime.datetime.strptime(
                                "2013-10-20 19:20:30.00", "%Y-%m-%d %H:%M:%S.%f"
                            ),
                        ),
                        last_run=null,
                        type=mozart_api.models.room_compensation_type.RoomCompensationType(
                            value="simple",
                        ),
                        version=mozart_api.models.room_compensation_version.RoomCompensationVersion(
                            algorithm=0,
                            coefficients=0,
                        ),
                    ),
                    tone_touch=mozart_api.models.sound_tone_touch.SoundToneTouch(
                        x=1.337,
                        y=1.337,
                        z=1.337,
                    ),
                ),
                source=mozart_api.models.source.Source(
                    id="0",
                    is_enabled=True,
                    is_playable=True,
                    name="0",
                    type=mozart_api.models.source_type_enum.SourceTypeEnum(
                        value="beolink",
                    ),
                ),
                tv=mozart_api.models.tv_state.TvState(
                    integration=mozart_api.models.tv_integration_types.TvIntegrationTypes(
                        value="ThirdParty",
                    ),
                    tv_info=mozart_api.models.tv_properties.TvProperties(
                        integration_supported=mozart_api.models.tv_integration_types.TvIntegrationTypes(
                            value="ThirdParty",
                        ),
                        name="0",
                        year=56,
                    ),
                ),
                volume=mozart_api.models.volume_state.VolumeState(
                    default=mozart_api.models.volume_level.VolumeLevel(
                        level=56,
                    ),
                    level=mozart_api.models.volume_level.VolumeLevel(),
                    maximum=mozart_api.models.volume_level.VolumeLevel(),
                    muted=mozart_api.models.volume_mute.VolumeMute(),
                ),
            )
        else:
            return ProductState()

    def testProductState(self):
        """Test ProductState"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mozart_api
from mozart_api.api.playback_api import PlaybackApi  # noqa: E501
from mozart_api.rest import ApiException


class TestPlaybackApi(unittest.TestCase):
    """PlaybackApi unit test stubs"""

    def setUp(self):
        self.api = mozart_api.api.playback_api.PlaybackApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_activate_preset(self):
        """Test case for activate_preset

        Trigger a preset  # noqa: E501
        """
        pass

    def test_add_to_queue(self):
        """Test case for add_to_queue

        Add an element to the queue  # noqa: E501
        """
        pass

    def test_get_available_sources(self):
        """Test case for get_available_sources

        Get all the available sources  # noqa: E501
        """
        pass

    def test_get_playback_state(self):
        """Test case for get_playback_state

        Get the current playback state  # noqa: E501
        """
        pass

    def test_get_settings_queue(self):
        """Test case for get_settings_queue

        Get the current queue settings  # noqa: E501
        """
        pass

    def test_post_clear_queue(self):
        """Test case for post_clear_queue

        Clear the queue  # noqa: E501
        """
        pass

    def test_post_playback_command(self):
        """Test case for post_playback_command

        Send a specific playback command to the product  # noqa: E501
        """
        pass

    def test_post_uri_source(self):
        """Test case for post_uri_source

        Set the URI from which sound is streamed  # noqa: E501
        """
        pass

    def test_seek_to_position(self):
        """Test case for seek_to_position

        Seek to position in stream  # noqa: E501
        """
        pass

    def test_set_active_source(self):
        """Test case for set_active_source

        Set the active source  # noqa: E501
        """
        pass

    def test_set_settings_queue(self):
        """Test case for set_settings_queue

        Set queue settings  # noqa: E501
        """
        pass

    def test_start_deezer_flow(self):
        """Test case for start_deezer_flow

        Play users flow. If no provided user id it will play the flow connected to the active account  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.paired_remote import PairedRemote  # noqa: E501
from mozart_api.rest import ApiException


class TestPairedRemote(unittest.TestCase):
    """PairedRemote unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test PairedRemote
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.paired_remote.PairedRemote()  # noqa: E501
        if include_optional:
            return PairedRemote(address="0", battery_level=0, name="0")
        else:
            return PairedRemote(
                address="0",
                name="0",
            )

    def testPairedRemote(self):
        """Test PairedRemote"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Mozart platform API

    API for interacting with the Mozart platform.  # noqa: E501

    The version of the OpenAPI document: 0.2.0
    Contact: support@bang-olufsen.dk
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mozart_api
from mozart_api.models.web_socket_event_hdmi_video_format_signal import (
    WebSocketEventHdmiVideoFormatSignal,
)  # noqa: E501
from mozart_api.rest import ApiException


class TestWebSocketEventHdmiVideoFormatSignal(unittest.TestCase):
    """WebSocketEventHdmiVideoFormatSignal unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WebSocketEventHdmiVideoFormatSignal
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # model = mozart_api.models.web_socket_event_hdmi_video_format_signal.WebSocketEventHdmiVideoFormatSignal()  # noqa: E501
        if include_optional:
            return WebSocketEventHdmiVideoFormatSignal(
                event_data=mozart_api.models.hdmi_video_format.HdmiVideoFormat(
                    pixel_format=mozart_api.models.video_pixel_format.VideoPixelFormat(
                        bitdepth="bit8",
                        chroma_subsample="yCbCr444RGB",
                        colorimetry="rGB",
                        full_range=True,
                    ),
                    v_ic=0,
                    video_timings=mozart_api.models.video_timings.VideoTimings(
                        horizontal_resolution=56,
                        interlaced=True,
                        refresh_rate=1.337,
                        vertical_resolution=56,
                    ),
                ),
                event_type="0",
            )
        else:
            return WebSocketEventHdmiVideoFormatSignal()

    def testWebSocketEventHdmiVideoFormatSignal(self):
        """Test WebSocketEventHdmiVideoFormatSignal"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
